Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: runtime/vm/raw_object.cc

Issue 8776020: Ongoing renaming of type classes: (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/raw_object.h ('k') | runtime/vm/raw_object_snapshot.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object.cc
===================================================================
--- runtime/vm/raw_object.cc (revision 1992)
+++ runtime/vm/raw_object.cc (working copy)
@@ -104,11 +104,11 @@
instance_size = Array::InstanceSize(array_length);
break;
}
- case kTypeArray: {
- const RawTypeArray* raw_array =
- reinterpret_cast<const RawTypeArray*>(this);
+ case kTypeArguments: {
+ const RawTypeArguments* raw_array =
+ reinterpret_cast<const RawTypeArguments*>(this);
intptr_t array_length = Smi::Value(raw_array->ptr()->length_);
- instance_size = TypeArray::InstanceSize(array_length);
+ instance_size = TypeArguments::InstanceSize(array_length);
break;
}
case kPcDescriptors: {
@@ -175,6 +175,7 @@
CLASS_LIST_NO_OBJECT(RAW_VISITPOINTERS)
#undef RAW_VISITPOINTERS
default:
+ OS::Print("Kind: %d\n", kind);
UNREACHABLE();
break;
}
@@ -227,19 +228,19 @@
}
-intptr_t RawTypeArguments::VisitTypeArgumentsPointers(
- RawTypeArguments* raw_obj, ObjectPointerVisitor* visitor) {
- // RawTypeArguments is an abstract class.
+intptr_t RawAbstractTypeArguments::VisitAbstractTypeArgumentsPointers(
+ RawAbstractTypeArguments* raw_obj, ObjectPointerVisitor* visitor) {
+ // RawAbstractTypeArguments is an abstract class.
UNREACHABLE();
return 0;
}
-intptr_t RawTypeArray::VisitTypeArrayPointers(RawTypeArray* raw_obj,
- ObjectPointerVisitor* visitor) {
+intptr_t RawTypeArguments::VisitTypeArgumentsPointers(
+ RawTypeArguments* raw_obj, ObjectPointerVisitor* visitor) {
intptr_t length = Smi::Value(raw_obj->ptr()->length_);
visitor->VisitPointers(raw_obj->from(), raw_obj->to(length));
- return TypeArray::InstanceSize(length);
+ return TypeArguments::InstanceSize(length);
}
« no previous file with comments | « runtime/vm/raw_object.h ('k') | runtime/vm/raw_object_snapshot.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698